#! /usr/bin/env python

# buildpage.py -- Charl P. Botha <cpbotha@ieee.org>
# generates static homepages with standard look'n'feel (my first python)

import sys, re, time

def usage():
    "Prints short instructions"
    print 'usage: buildpage.py templatefile pagename outputdir'
    
def handleIncludeFile(includefilename, outputfile):
    "includes specified file into outputfile"
    try:
	includefile = open(includefilename,'r')
    except IOError:
	sys.stderr.write('Error opening ' + includefilename + '!\n')
	sys.exit(2)
    include = includefile.read()
    outputfile.write(include)
    
def handleFunction(funcName, outputfile):
    "if a $funtion is found, this handles it"
    if funcName=='lastupdate':
	outputfile.write('last update on ' + time.ctime(time.time()))
    elif funcName=='menu':
	handleIncludeFile('quicklinks.html', outputfile)
    
def handleMarkup(line, pagename, outputfile):
    "parses and reacts on line with our extracted markup"
    name = line[1:]
    if line[0]=='@':
	includefilename = pagename + '_' + name + '.html'
	handleIncludeFile(includefilename, outputfile)
    elif line[0]=='!':
	handleIncludeFile(name, outputfile)
    elif line[0]=='$':
	handleFunction(name, outputfile)

def main():
    print 'buildpage.py -- <cpbotha@ieee.org>\n'
    if len(sys.argv) < 4:
	usage()
	sys.exit(2)

    try:
	templatefilename = sys.argv[1]
	templatefile = open(templatefilename, 'r')
    except IOError:
	sys.stderr.write('Error opening template file.\n')
	sys.exit(2)
	
    try:
	outputfilename = sys.argv[3] + "/" + sys.argv[2] + ".html"
	outputfile = open(outputfilename, 'w')
    except IOError:
	sys.stderr.write('Error opening output file.\n')
	sys.exit(2)

    template = templatefile.readlines()
    for tline in template:
	mo = re.compile("<!--.*:::(.*):::.*-->").search(tline)
	if mo:
	    handleMarkup(mo.group(1), sys.argv[2], outputfile)
	else:
	    outputfile.write(tline)
    
main()
